@@ -72,7 +72,7 @@ ldapbase = data['hubzero']['hubLDAPBaseDN']
 ldaphost = data['hubzero']['hubLDAPMasterHost']
 ldapbinduser = data['hubzero']['hubLDAPSearchUserDN']
 ldapbindpass = data['hubzero']['hubLDAPSearchUserPW']
-ldapgroupobjectclass = 'hubGroup'
+ldapgroupobjectclass = 'posixGroup'
 try:
   ldapgroupobjectclass = data['hubzero']['hubLDAPGroupObjectClass']
 except:
